@@ -1,3 +1,4 @@
+from nwon_django_toolbox.fields.lower_case_email_field import LowercaseEmailField
 from nwon_django_toolbox.fields.pydantic_json_field import (
     ModelSerializerWithPydantic,
     PydanticJsonField,
@@ -10,6 +11,7 @@ from nwon_django_toolbox.fields.serializer_choice_field_for_polymorphic_ctype_id
 __all__ = [
     "serializer_choice_field_for_polymorphic_ctype_id",
     "PydanticJsonFieldSerializer",
+    "LowercaseEmailField",
     "PydanticJsonField",
     "ModelSerializerWithPydantic",
 ]
