@@ -6,7 +6,7 @@ from nwon_baseline.file_helper import read_file_content
 
 
 def read_fixture_file(fixture_path: str) -> List[dict]:
-    if path.isfile(fixture_path):
+    if not path.isfile(fixture_path):
         return []
 
     fixture_json = read_file_content(fixture_path)
