@@ -7,7 +7,7 @@ from nwon_django_toolbox.tests.api_method_tests import (
     check_get_detail_permissions,
     check_get_list_permissions,
     check_patch_basics,
-    check_patch_not_allowed,
+    check_patch_method_not_allowed,
     check_patch_parameters_failing,
     check_patch_parameters_successful,
     check_patch_permissions,
@@ -41,6 +41,7 @@ from nwon_django_toolbox.tests.celery import (
 )
 from nwon_django_toolbox.tests.helper import (
     check_object_against_parameter,
+    dictionary_is_serialized_instance,
     get_path_to_random_image,
     get_random_image,
     get_random_tempfile_path,
@@ -66,7 +67,7 @@ __all__ = [
     "check_delete_not_allowed",
     "check_get_basics",
     "check_patch_basics",
-    "check_patch_not_allowed",
+    "check_patch_method_not_allowed",
     "check_patch_parameters_failing",
     "check_patch_parameters_successful",
     "check_patch_read_only_field",
@@ -90,8 +91,10 @@ __all__ = [
     "check_get_detail_permissions",
     "check_get_list_permissions",
     "check_patch_permissions",
+    "check_post_parameters_required",
     "check_permission",
     "check_permissions",
     "check_post_permissions",
     "check_put_permissions",
+    "dictionary_is_serialized_instance",
 ]
