@@ -1,6 +1,9 @@
 from nwon_django_toolbox.tests.helper.check_object_against_parameter import (
     check_object_against_parameter,
 )
+from nwon_django_toolbox.tests.helper.dictionary_is_serialized_instance import (
+    dictionary_is_serialized_instance,
+)
 from nwon_django_toolbox.tests.helper.random_image import (
     get_path_to_random_image,
     get_random_image,
@@ -14,4 +17,5 @@ __all__ = [
     "get_path_to_random_image",
     "get_random_image",
     "get_random_tempfile_path",
+    "dictionary_is_serialized_instance",
 ]
