@@ -13,10 +13,12 @@ from nwon_django_toolbox.typings.permissions import (
 )
 from nwon_django_toolbox.typings.pydantic_base_django import PydanticBaseDjango
 from nwon_django_toolbox.typings.request_body_format import RequestBodyFormat
+from nwon_django_toolbox.typings.seed_set import SeedSet
 from nwon_django_toolbox.typings.test_fixture import Fixture
 
 __all__ = [
     "ErrorResponse",
+    "SeedSet",
     "CeleryFolder",
     "CeleryReturn",
     "Fixture",
